# dataframe_to_netcdf

This function encodes an existing Dataframe into a NetCDF file following [CF & in-situ conventions](../conventions)

```{eval-rst} 
.. autofunction:: libinsitu.dataframe_to_netcdf
```